@@ -1,9 +1,10 @@
-__all__ = ["Layer", "Raster", "composite", "slope", "aspect", "distance", "fuel", "gui"]
+__all__ = ["Layer", "Raster", "composite", "slope", "aspect", "height", "distance", "fuel", "gui"]
 
 from .containers.layer import Layer
 from .containers.raster import Raster
 from .gui.gui import gui
 from .processes.composite import composite
+from .processes.height import height
 from .processes.distance import distance
 from .processes.fuel import fuel
 from .processes.topography import aspect, slope
