@@ -6,95 +6,95 @@
 from PySide6 import QtCore
 
 qt_resource_data = b"\
-\x00\x00\x05o\
+\x00\x00\x05m\
 \x00\
-\x00\x1c\xb3x\xda\xd5YQO\xe38\x10~\xaf\xd4\xff\
-\x10-/w\x88l\x0bm\xba\x5c\xfa\x04\x05vW\xe2\
-\xc4r\xa0C\xf7\x84\xdc\xc4m\xadu\xed\x9c\xed\xd2\xc2\
-\x8a\xff~c\xa7I\x9d\xd4mS\xda\xe5\xee\x12\xb1K\
-\xc6\xf6\xe4\xfbf\xec\x99\xc9\xd08\xac\xd7\xea\xb5\xde\xcd\
-\xf5\xcd\x1f\xde\xf5\xd7\xbb{\xfd\xf4\x8d\x22E\xd8d\x1c\
-z\x07\x97\xcd\xcb\xd6e\xab^{\x18\x11\x85\xe1\xf9\xca\
-\x5cz\xd2=F\x14\x04\xad\xab\xe0SpR\xaf}\x16\
-\x183x\x0e\x9a\x9dV\xd0\xae\xd7n(y\xd2\x0b:\
-\xbdO\xcd\xf6\x85^\xf0\x17\xa6\x94OAtqv\xd6\
-k\x19\xd19E\xd1w\x904\xcd\xa5%\x87\x0d\xfdo\
-\xe3\xd0\xfb\x1d\x11\xe6=\x10\x16\xf3\xa9\xf4\x10\x8b\xbdo\
-\x88a*\xbdt\xc2\xc1\x18\x86\xfd\xa9\x19\xf6~\xd4k\
-\x1e\x5c}\xd05\x14|\xc2b?\xe2\x94\x0b\x8d\xb6\xa9\
-\xefn:\x9e\xa08&l\x18z\xc7\xcdd\x06\xb2W\
-\xa3\x88O\x14\x16~\xa2\x95\xafSty\xd5\xbb\xba\x98\
-+\xeas\x11\xc3\x1a\x81b2\x91\xb9\xba\xc5H\xe8\x9d\
-$3OrJb \x1b\xe8\xbb\xb8R\xaag\x0a\xb6\
-!Lb\x95\x01\x01\xcaw\x91\xe0\x94z\xd7D\xaa\x8c\
-\xa64\x22\x9fj\xd1jt\xa9\x93Vcp\x8c\x97\xd1\
-\x970|Ux\x9ca\xa0\xe8\x19\xe6\x13-Y\x0d!\
-\xf5`\xa5W\x5c\xa3\xbe\xe5HE\x14\xc5>\xd5\xb2L\
-}\xae\xb3\xa7\xefn\xf9\x9d\xa1\xc78\xc3%\xb6\x96h\
-\xc0\x99\xf2\x07hL\xe8s\xe8}\xf8\x82\xe9\x13V$\
-B\x1f\x8e<\x89\x98\xf4%\x16d`O\x95\xe4\x05\x9c\
-q\xdc\xc9\xbd\x98o\x94f\xbeK$\x19'[\xc3<\
-^\xeb\x01\x07\x0d\xd7\x96z#\x9b\x13\x07\x1b/\xb0\xf6\
-\xbd\xcd\xc8g\xdc\xef\x0f\xf7d\xfew\xa7\x02[\xaa7\
-\xc2\xd1w\xef\x9c\xcf\xe6\xbb\xea\xd6\x08\xe09\x0c!D\
-\xc0;\x14\x17\xebN\xb7\xb9*\x9en\x88:\xb1\x1a\x01\
-\x86\xa5So\xf9;\x0dq\xf3\xf1\xf9\x82\xe3 _1\
-\xc2d8R\x05Q\xce\xed$c\xe6\x22\x11FZ\x86\
-\xe35d\x0a\xaf\xde\x04m5\xd9J\xa0\xc9\x18\x0d\xc1\
-E\x13A\x7f\x09\x1b$\xe2L6\x0c\xc0\x8f\xf2i\xf8\
-\xebb\xabM\x89\x8aF\xbe\xe2\xc3!\xec\xb8\xe4\xa9\x9a\
-SN\x9b\xfav\xe3\x0c\xde\xe2\x93\x82\xc2\xf9\x82\x93\xe6\
-\x12=K\x94\xfb\xa4\xbd\x8e\xf1\x0b\xe7c_F\x88Y\
-\xac\x979\xbf\x97\x0b\x83\xb2\x07\xd7S\xac\xc8\xc7\x9c\xb2\
-\xcb\x98(\xc8N\x0cg\xb1\x1b\x83\x00r\x13\x08\x0c\x97\
-\xa5`0\x87\xd6\xe7J\xf1\xf1\xb2|i\xd7\xd9A\xc6\
->\x94\x95\x03\x87#\x1b\xe5>\x04\xc3,\xa2\xc6\x02z\
-8\xe0\xd1DV#\xe0v\xc1\xbf\xcf\xc6x\xe7|\x02\
- Y\x9eW\x93\x89\x1c\xf9}#[\xb3\xd3\xd2\xea\xad\
-r0w\x84++d\x8c\x91\x18\x12f\xcfr\x06\xd8\
-\xb1\xa9\xdc\xd2\xe8b/\x9e\xb9\xa407\x8f;\xc5\xc9\
-%\xf1k\x91s8\xe2Ox]xi\x9fu:\x9d\
-,\x1aD\x13!\xb54\xe1\x84A9\xe8P\x97\x08,\
-\xe5\xdaC\xdbj\xb7O\xdb\xed<\xe8Y\x8b}\x85g\
-\xeag8a\x8b\x84\xba\xa3\xbf\xde\xe4\x03\xc3{\xcf\x8e\
-Hu\xee\xe4\x8d\xa1 \xf1\x7f\xe8H\xbc:\xe0\xed\xdb\
-hF\xe7\xd6F\x03\xc7\x13\xff\x7f\x11G\x02W\x18\x09\
-\x9cQ$pn\xe0Eb(\x93\xde\x87+\x96tn\
-\xeb\x0a\xfda\x96\xc0\xf7\xf0\xa2\xc2=\x90\xf0\x0c\x89i\
-vd\xfd\x1e\xea\xac\x86\xfa\x14\x17\x84\x86@ARx\
-\xfd\x16I\xcf2\xff\xb6IoS.k/~\xb2\x0a\
-*C\xfb\xee\x09z\x07\xac1\x91\xda\xfe\xdb\x9b\xf67\
-sU\x87k\xcd\xdf\x04\xf78X\x8d7\x9c$\x85\xc3\
--'}\xa8\x01\x95\xe0\xd4\xe7\x82\x98S\x98\xc2\xe9\x96\
-F\x13.\x89\x22\xb0\x95=\xc5\x13O\xe8S\xd4]G\
-\xb9\xb2\xf1\xd3\xc3\x0f\x85sb\xec\xb3\x048\xe6S\xb6\
-+\xe4\xd4\xfe\xfbC\xbddR$D\xd6\x97r\x14\xd8\
-J\x10\xc4\xf4g\xc1\x80P\xd8+Y\x99]\x88h\xd9\
-G\xaf\x15\xcfr\x91\x15\xcd\xeciE\x99\x1bS\xbeA\
-\x8f\xdc\xc3|0(\xc0\x9e\x1b\xc4\xe1\x82\x8a\x14\x09\x83\
-\xe0\xa3p\xfc\x8e\x5c\x17\xf0V\xb0\xb5&\xac\xe6k\x82\
-\xee=\xe7\xd4\xbb'I\xd6V\xd0\xcf\xfa\xf1\xc7\xf6\x89\
-nS\xdb\xc1\xd9u\xd9_\xc7$Op\x19\x87\x83\xbf\
-\xd5\xa3\x22\xc9\xe3\xe6\x96\xd6N rK\xa2\xbe\xcc\xad\
-\x88\xfa\x0f$\x1eb\x15\x86\xba\xefZ\xb6\xa6\x15\x15\x0b\
-eEV\x168\xbe\xcf\xad\x06\xa3\xd6~\x8eD\x18B\
-\x22\xacZ\xb0\xcc\x85S\xdd\xe3\xeeV\x033\xf73\x84\
-)\x9f\xe2\x81Z\xd3.\xd2SL\xa4\xf9)-1\xeb\
-\x18\x9d\xael\x5c\xbc\x16\xcd\x12JLq\xa4\xaa\xd5\x1f\
-\xab\x8ca\xd5'\x05\xdd[\x95K\x0e\xc5\xf9x^\xf8\
-\x80\x18\x8b\xfc\xbbV\x9a\xc70\x1c!\x16S\x0c\xaf\x13\
-\xe4\x05,\x83\xe8v\xfd\x94\xd2\x09}u\xe9\xd6\x91\x0b\
-\x9c\xb1\x07\xcd@\xe3\xb3@\xc9\x88D\xd2\xbb\x8b0\xc3\
-\x8d?\x09\x9e\x1aJ\xb7\xd9\x80\x91\xbc\xadG\x19Tj\
-{\xa5\xc7#{\x9d\x81\xb1\xd3\xfb\xf2\xe6+\x1f\xf7y\
-\xa1\xf9\xaa\x05\xfay\xb5\xf6AS\xdf\xabA[\xe5\xcd\
-\x22*\xb5\xcc\xe5\xe8\x97z\xa7\xf0\xa3\xffo\xb9\x0fV\
-~\xae\xaa\x86\xac\x9c\x02$\x0b\x01\xe7Wg\x8c\x8c\x8d\
-\xa3\xde\x98c\xe9.MX\x94\x1c&\x02\xe8Zie\
-snnc\x1dM\xdc\xa6(\xe1*%\xe1B\x1a\xd6\
-\x83\x8ff\xf0c\xc2\xb2\x1e\xde\xc2/\xb7g}\xa9\x04\
-\x8a\x94\xfe3\xcf\x86}70WEO\xa5\x81\x05\x08\
-\xfb\x0eM\xb8\xa9\xef=\xf8\xe7\x1fm\x9ad>\
+\x00\x1a\xe1x\xda\xbdX]O\xe38\x14}\xaf\xd4\xff\
+\x10\x0d/\xbb\x88l\x0bM:Lx\x82\x023#\xb1\
+\x02\x16\xb4h\x9fFn\xe2\xb6\xd6\xb8v6via\
+\xc4\x7f\xdfk\xa7I\x9c\xc6M\x13`I\x04\xaa\xaf\x1d\
+\xfb\xdc\xaf\xe3k\xf7\xf6\xbb\x9dngt}u\xfd\x97\
+s\xf5\xfd\xee^\xb5n(\x92\x84-\xe6\x81\xb3w\xd1\
+\xbf\x18\x5c\x0c\xba\x9d\x87\x19\x91\x18\xda\x97\xfaQ\x83\xee\
+1\xa2 \x18\x5c\xfa\x9f\xfd\xa3n\xe7k\x821\x83\xb6\
+\xdf\x1f\x0e|\xaf\xdb\xb9\xa6\xe4Q}0\x1c}\xee{\
+\xe7\xea\x83\x7f0\xa5|\x09\xa2\xf3\xd3\xd3\xd1@\x8b\xce\
+(\x0a\x7f\x82\xa4\xaf\x1f%\xd9\xef\xa9\xff\xbd}\xe7O\
+D\x98\xf3@X\xc4\x97\xc2A,rn\x10\xc3T8\
+\xe9\x80\xbd9t\xbbK\xdd\xed\xfc\xeav\x1cx\xc60\
+\xd74\xe1\x0b\x16\xb9!\xa7<Qh\xfb\xea=I\xfb\
+c\x14E\x84M\x03\xe7\xb0\x1f\xaf@\xf6\xa2'\xe2\x0b\
+\x89\x137V\x93\xd7Mtq9\xba<_O4\xe6\
+I\x04\xdf$(\x22\x0b\x91OW\xf4\x04\xceQ\xbcr\
+\x04\xa7$\x02e}\xf5\x96\xbf\x14\xf2\x89\x82m\x08\x13\
+Xf@@\xe5\xbb0\xe1\x94:WD\xc8LM\xa1\
+E.U\xa2\xed\xe8R'm\xc7`\xe9\xdfD\xbf\x81\
+\xe1\xbb\xc4\xf3\x0c\x03EO0\x9e(\xc9v\x08\xa9\x07\
+\x1b-q\x85\xc6\x86#%\x91\x14\xbbT\xc9\xb2\xe9\xf3\
+9G\xea=\xd9\x5c3p\x18gxC[C4\xe1\
+L\xba\x134'\xf4)p>}\xc3\xf4\x11K\x12\xa2\
+O\x07\x8e@L\xb8\x02'db\x0e\x15\xe4\x19\x9cq\
+8\xcc\xbd\x98\x07J?\x8f\x12A\xe6qk\x98\x87\xb5\
+\x1e\xb0\xa8a\x0b\xa9Wjsd\xd1\xc6\xf1\x8d\xb87\
+5r\x19w\xc7\xd3w2\xff\x87\xab\x02!5\x9a\xe1\
+\xf0\xa7s\xc6W\xeb\xa8\xba\xd5\x02h\x07\x01P\x04\xac\
+!yR\x97\xdd\xfa\xd9P\xc9\xf0^JXv\xfd\xfc\
+\x1c\xdd\x92Dr\x06\xdf\x15\x92\x19&\xd3\x99,\x89r\
+\x15\xbcL\x01\x1b\xd6 T2\x1c\xd5`\xb6`\xda\x8e\
+\x99\xcc\xd1\x14L\xb9H\xe8oA\x8f\x84\x9c\x89\x9e^\
+\xe1\x0f\xf18\xfd\xbd\x06FD\x04\x1a\xd3Z\x1c\xbbl\
+w6Po\x11vK\x22\xc3\x99+\xf9t\x0a\xd1\x17\
+?6s\xd0q_\xbd\xdb\x17)\xf5\xaf\xfdp\xd4\xaf\
+\xf8\xc1\x10Y,\xf2\xcc\xf9\xdc\x15!b\x86U\xea\xf0\
+\xbe\xa7\x93v-\xd5\xc0\x11\xb9\xa1\x1b9\x02\x92\xe6\x22\
+\x22\x126\x1b\x863*\xc6 \x80\xad\x06\x04z\x95J\
+n\xaf#\x7f\xcc\xa5\xe4\xf3\xaa\xbc\x92\xf1&g\x98q\
+\xd2\x98\x07,\x9bK\x9e?\x90R\x05\x09\x14\xd0\x83\x09\
+\x0f\x17\xc2T \xc7\xbb\xc5\xee\xda\x16g\x0b\x18\xc3\xb2\
+M\xe9\xf6f!f\xa9\xa8\xc6\xe0i\xe5\xd3\x98\x08-\
+\x1c`p\xe3\x1c%S\xc2\xccQ\xd6\x04kh\xba\x97\
+\x92\x0e\xc1\x8c?\xe2\xba\xf4\xf2N\x87\xc3a\x96>\xe1\
+\x22\x11J\x1as\xc2\xa04\xaa\xce\x16'X\x88\xdaP\
+\x1cx\xde\xb1\xe7U\xbfl\x13\xc5)]\xc4\xf0\xb1;\
+.yb\xae\x0b\xbf\x94jM\xfb\xadlR\x18\x9b\x93\
+py\xf0\x86\xb8\xb2\x9c+\xf1J\x9ak\xb6\x99\x07\xc6\
+\x13\xb7\x1e\xbbo\x83\xee[\x91\xfb\xd6\x05\xcb;\xe0]\
+\x0c\xe5r\xb1\x01\xee\x09hC\xe4\xaf\x0e\x8c\xdf\x81\xca\
+\x12\xe5\x80\x92P\x07GIRr\xf0.\x160\xb2\xca\
+\x88\xd4\xb6\x94\xb0+\xd3\xbd\xe2/c\xcb\x0cm%\xe1\
+\x1ba5\x98\xf9\x03\xb1\x96\x13\xa0\x05\xdc/\xfai\x0e\
+\xd7\x18\xbf\x0b\xee\xa1\xbf\x1do\xb0\x88K\x11,\x16c\
+\xd8*%\x1c\x11\x5c\x9e\x10MX)\x9c\x93\x8d\xde\x98\
+\x0b\x22\x09\xa4\xbc#y\xec$*bO\xeaTnl\
+\xfc\x94'a\x93\x8c\xb5}*\x80\xe1<\xc8\xde\x0a9\
+\xb5\xff\xfb\xa1\xae\x98\x14%Ivl\xb5\xd4!2!\
+\x88\xa9\x12`B(\xc4JV\x8d\x94\xd8#\xab\x89\x0d\
+\xee\xc8E\x06s\x98\xc3\xca2;\xa6<@\x0f\xec\xdd\
+|2)\xc1^\x1b\xc4\xe2\x82\x86*\x12\x06\xe4#q\
+\xf4\x81\xba\x16\xf0\xb6hk\x0c\xd8\xae\xaf&\xdd{\xce\
+\xa9sO\xe2\xaclPm\xd5\xfc\xd5\xbe&\xd8UY\
+[\x0fe\xefw\xa0\xca7\x93L\x87\xbd\x7f\xe5\x0fI\
+\xe2\x1f\xbbO\xbco\x02\x91[\x12\x8d\xf3\xe2\x0b~?\
+\x90h\x8ae\x10\xa8k\x99Mk\x1a\xacX\xaa\xc0\xb2\
+\x0a\xaao9.\x16k\xa9\xd9\xcfP\x12\x04\xb0\x116\
+\xad\xed\xd6\xc2\xa5\xba\x02;i\x06f\xedg\xa0)\x97\
+\xe2\x89\xdc~W\xa4\x87h\xa6\xf9_N\xccF\x1a\x1d\
+\xf7\xeb\x0e\xa1\x86Y\x02\x81)\x0ee\xb3\x0ao\x9b1\
+\xcc\x0a\xd0\x9c\xbbU)j\x998\xef\xcf\x0b\x1f\x10\xe3\
+$\xbfN\x12\xba\x19\x043\xc4\x22\x8aa\xb9\x84<\x83\
+e\x10mwJ\xdb\xc8\xd0\x97\xba\x99\xdb\x96\xb5\x9b3\
+)\x06\x04\xa7\xbe;\xc2l\xde\xf6e7\x98\xf5k\x82\
+\xe2\x19\x09\x85s\x17b\x86{\x7f\x13\xbc\xd4&\xbe\xcd\
+:\xb4\xa4\xd5\xb5\x80\x8d\xf5j\x8e\xf2i\xbaf\xcbi\
+\x18oZ/\xbf+\xe2\xf31/\xdd\x15)\x81j\xb7\
+\x9b\xddR\xa5\xd9(\xc0\x92\xd5V\x1a\xcdsR\xdd\xdb\
+\xaa\xc1\xfa\x87o\xa7\x82\x9c\x09\x9a\x92l\xae\xe4+\xaf\
+tl\xda\x9a1S\xcc\x1fD\x090\x9a\xdaC_\xe9\
+\xad/u\xd1Q\xb2\xb0\xa5\xb4[[\xb1:\xa0\xa8\xee\
+4\xd9\xaa\xb2t\xe3\xba\xc8\xaf\xda\xaa\xd0\xa5j\xb6\xfa\
+\x0b\x16s\x8e\x8dr\xe8\x95\x05Q\x89\xcb=\xdb\xe1\xd1\
+\xb3\x1e\x1e=\xeb\xe1\xd1\xab(\xeb\xdc\x9e\x8e\x85LP\
+(\xd5\xdd\x7f\xfb\xecn\x9c\x08EH\xa7\xfb\x0c8\xc5\
+\xddEyo\x09\xfe\xff\x00\x12\xed\xe6-\
 \x00\x00\x01\x94\
 <\
 svg xmlns=\x22http:\
@@ -677,6 +677,36 @@ th d=\x22M4 16v2a2 \
 \x22 />\x0a  <path d=\x22\
 M16 16l-2.5 -2.5\
 \x22 />\x0a</svg>\x0a\x0a\x0a\
+\x00\x00\x01\xc0\
+<\
+svg xmlns=\x22http:\
+//www.w3.org/200\
+0/svg\x22 class=\x22ic\
+on icon-tabler i\
+con-tabler-line-\
+height\x22 width=\x222\
+4\x22 height=\x2224\x22 v\
+iewBox=\x220 0 24 2\
+4\x22 stroke-width=\
+\x222\x22 stroke=\x22whit\
+e\x22 fill=\x22none\x22 s\
+troke-linecap=\x22r\
+ound\x22 stroke-lin\
+ejoin=\x22round\x22>\x0a \
+ <path stroke=\x22n\
+one\x22 d=\x22M0 0h24v\
+24H0z\x22 fill=\x22non\
+e\x22/>\x0a  <path d=\x22\
+M3 8l3 -3l3 3\x22 /\
+>\x0a  <path d=\x22M3 \
+16l3 3l3 -3\x22 />\x0a\
+  <path d=\x22M6 5l\
+0 14\x22 />\x0a  <path\
+ d=\x22M13 6l7 0\x22 /\
+>\x0a  <path d=\x22M13\
+ 12l7 0\x22 />\x0a  <p\
+ath d=\x22M13 18l7 \
+0\x22 />\x0a</svg>\x0a\x0a\x0a\
 \x00\x00\x01\x9a\
 <\
 svg xmlns=\x22http:\
@@ -1061,6 +1091,10 @@ qt_resource_name = b"\
 \x0b\xcdQ\xe7\
 \x00z\
 \x00o\x00o\x00m\x00-\x00s\x00c\x00a\x00n\x00.\x00s\x00v\x00g\
+\x00\x0f\
+\x04\xf1A'\
+\x00l\
+\x00i\x00n\x00e\x00-\x00h\x00e\x00i\x00g\x00h\x00t\x00.\x00s\x00v\x00g\
 \x00\x0c\
 \x09\x8c\xd1\x87\
 \x00m\
@@ -1097,60 +1131,55 @@ qt_resource_struct = b"\
 \x00\x00\x00\x00\x00\x02\x00\x00\x00\x02\x00\x00\x00\x01\
 \x00\x00\x00\x00\x00\x00\x00\x00\
 \x00\x00\x00\x10\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\
-\x00\x00\x01\x8d^\xe8\x1c\xbd\
-\x00\x00\x00\x00\x00\x02\x00\x00\x00\x13\x00\x00\x00\x03\
+\x00\x00\x01\x8du_5\xb8\
+\x00\x00\x00\x00\x00\x02\x00\x00\x00\x14\x00\x00\x00\x03\
 \x00\x00\x00\x00\x00\x00\x00\x00\
-\x00\x00\x00(\x00\x00\x00\x00\x00\x01\x00\x00\x05s\
+\x00\x00\x00(\x00\x00\x00\x00\x00\x01\x00\x00\x05q\
 \x00\x00\x01\x8d_5s4\
-\x00\x00\x02z\x00\x00\x00\x00\x00\x01\x00\x008\x84\
+\x00\x00\x02\x9e\x00\x00\x00\x00\x00\x01\x00\x00:F\
 \x00\x00\x01\x8d_5s.\
-\x00\x00\x02\x08\x00\x00\x00\x00\x00\x01\x00\x00+\x94\
+\x00\x00\x02,\x00\x00\x00\x00\x00\x01\x00\x00-V\
 \x00\x00\x01\x8d@\x8dh\x96\
-\x00\x00\x01\xe0\x00\x00\x00\x00\x00\x01\x00\x00)\xbe\
+\x00\x00\x02\x04\x00\x00\x00\x00\x00\x01\x00\x00+\x80\
 \x00\x00\x01\x8dU:\x8cG\
-\x00\x00\x01T\x00\x00\x00\x00\x00\x01\x00\x00 \xbb\
+\x00\x00\x01\xc2\x00\x00\x00\x00\x00\x01\x00\x00(\x1e\
+\x00\x00\x01\x8dk\xb9p\x96\
+\x00\x00\x01T\x00\x00\x00\x00\x00\x01\x00\x00 \xb9\
 \x00\x00\x01\x8dUA\xbf\x04\
-\x00\x00\x00\x92\x00\x00\x00\x00\x00\x01\x00\x00\x08\xfa\
+\x00\x00\x00\x92\x00\x00\x00\x00\x00\x01\x00\x00\x08\xf8\
 \x00\x00\x01\x8d@\x84\xa1\x8c\
-\x00\x00\x00T\x00\x00\x00\x00\x00\x01\x00\x00\x07\x0b\
+\x00\x00\x00T\x00\x00\x00\x00\x00\x01\x00\x00\x07\x09\
 \x00\x00\x01\x8dJZ\x0e-\
-\x00\x00\x01v\x00\x00\x00\x00\x00\x01\x00\x00\x22\xa2\
+\x00\x00\x01v\x00\x00\x00\x00\x00\x01\x00\x00\x22\xa0\
 \x00\x00\x01\x8d_5s+\
-\x00\x00\x01\xc2\x00\x00\x00\x00\x00\x01\x00\x00( \
+\x00\x00\x01\xe6\x00\x00\x00\x00\x00\x01\x00\x00)\xe2\
 \x00\x00\x01\x8d_5s0\
-\x00\x00\x00\xa8\x00\x00\x00\x00\x00\x01\x00\x00\x17\xe4\
+\x00\x00\x00\xa8\x00\x00\x00\x00\x00\x01\x00\x00\x17\xe2\
 \x00\x00\x01\x8dJZ\x0e*\
-\x00\x00\x00\xd4\x00\x00\x00\x00\x00\x01\x00\x00\x19\xea\
+\x00\x00\x00\xd4\x00\x00\x00\x00\x00\x01\x00\x00\x19\xe8\
 \x00\x00\x01\x8dJ?\xa3\xc6\
-\x00\x00\x01\x0a\x00\x00\x00\x00\x00\x01\x00\x00\x1d:\
+\x00\x00\x01\x0a\x00\x00\x00\x00\x00\x01\x00\x00\x1d8\
 \x00\x00\x01\x8dB\x0f\xbc\xc2\
-\x00\x00\x01>\x00\x00\x00\x00\x00\x01\x00\x00\x1e\xe6\
+\x00\x00\x01>\x00\x00\x00\x00\x00\x01\x00\x00\x1e\xe4\
 \x00\x00\x01\x8dB\x0f\xbc\xbe\
-\x00\x00\x02b\x00\x00\x00\x00\x00\x01\x00\x007G\
+\x00\x00\x02\x86\x00\x00\x00\x00\x00\x01\x00\x009\x09\
 \x00\x00\x01\x8dT\xb0.\xe4\
-\x00\x00\x00\xee\x00\x00\x00\x00\x00\x01\x00\x00\x1bj\
+\x00\x00\x00\xee\x00\x00\x00\x00\x00\x01\x00\x00\x1bh\
 \x00\x00\x01\x8dB\x0f\xbc\xbf\
-\x00\x00\x01\xa2\x00\x00\x00\x00\x00\x01\x00\x00&\x0d\
+\x00\x00\x01\xa2\x00\x00\x00\x00\x00\x01\x00\x00&\x0b\
 \x00\x00\x01\x8dUS\xeb\x1d\
-\x00\x00\x01\x8e\x00\x00\x00\x00\x00\x01\x00\x00$^\
+\x00\x00\x01\x8e\x00\x00\x00\x00\x00\x01\x00\x00$\x5c\
 \x00\x00\x01\x8dB\x0f\xbc\xbc\
-\x00\x00\x02D\x00\x00\x00\x00\x00\x01\x00\x005\x8d\
+\x00\x00\x02h\x00\x00\x00\x00\x00\x01\x00\x007O\
 \x00\x00\x01\x8dB'7\xb7\
-\x00\x00\x02(\x00\x00\x00\x00\x00\x01\x00\x004\x09\
+\x00\x00\x02L\x00\x00\x00\x00\x00\x01\x00\x005\xcb\
 \x00\x00\x01\x8d_5s2\
 "
 
-
 def qInitResources():
-    QtCore.qRegisterResourceData(
-        0x03, qt_resource_struct, qt_resource_name, qt_resource_data
-    )
-
+    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)
 
 def qCleanupResources():
-    QtCore.qUnregisterResourceData(
-        0x03, qt_resource_struct, qt_resource_name, qt_resource_data
-    )
-
+    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)
 
 qInitResources()
